@@ -8,7 +8,7 @@ use strict;
 
 use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS $VERSION %HTLC_COLORS);
 
-$VERSION = '0.76';
+$VERSION = '0.77';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -52,7 +52,8 @@ HTXF_PARTIAL_TYPE HTXF_RESUME_MAGIC HTXF_RFLT_MAGIC HTXF_TCPPORT
 PATH_SEPARATOR SIZEOF_HL_DATA_HDR SIZEOF_HL_FILE_FORK_HDR
 SIZEOF_HL_FILE_LIST_HDR SIZEOF_HL_FILE_UPLOAD_HDR SIZEOF_HL_FILE_XFER_HDR
 SIZEOF_HL_LONG_HDR SIZEOF_HL_PROTO_HDR SIZEOF_HL_SHORT_HDR
-SIZEOF_HL_TASK_FILLER SIZEOF_HL_USER_LIST_HDR MACOS_MAX_FILENAME);
+SIZEOF_HL_TASK_FILLER SIZEOF_HL_USER_LIST_HDR MACOS_MAX_FILENAME
+HTLS_DATA_REPLY HTLS_DATA_IS_REPLY);
 
 %EXPORT_TAGS = ('all' => \@EXPORT_OK);
 
@@ -189,6 +190,8 @@ use constant HTLS_HDR_USER_LEAVE        => 0x0000012E;
 use constant HTLS_DATA_AGREEMENT        => 0x0065;
 use constant HTLS_DATA_CHAT             => 0x0065;
 use constant HTLS_DATA_COLOR            => 0x0070;
+use constant HTLS_DATA_REPLY            => 0x00D6;
+use constant HTLS_DATA_IS_REPLY         => 0x0071;
 use constant HTLS_DATA_ICON             => 0x0068;
 use constant HTLS_DATA_NEWS             => 0x0065;
 use constant HTLS_DATA_NICKNAME         => 0x0066;
